@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     wangchunlin<wangchunlin@uniontech.com>
- *
- * Maintainer: wangchunlin<wangchunlin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef ENTRANCEWIDGET_H
 #define ENTRANCEWIDGET_H
 
@@ -26,6 +10,8 @@
 #include <QFrame>
 #include <QScopedPointer>
 
+namespace GrandSearch {
+
 class EntranceWidgetPrivate;
 class EntranceWidget : public QFrame
 {
@@ -46,7 +32,7 @@ private:
 
 public slots:
     // 切换选择搜索结果时，应用图标发生改变
-    void onAppIconChanged(const QString &searchGroupName, const GrandSearch::MatchedItem &item);
+    void onAppIconChanged(const QString &searchGroupName, const MatchedItem &item);
 
 signals:
     void searchTextChanged(const QString &txt);
@@ -59,4 +45,6 @@ private:
     QScopedPointer<EntranceWidgetPrivate> d_p;
 };
 
+}
+
 #endif // ENTRANCEWIDGET_H
