@@ -1,26 +1,9 @@
-/*
- * Copyright (C) 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     zhangyu<zhangyub@uniontech.com>
- *
- * Maintainer: wangchunlin<wangchunlin@uniontech.com>
- *             zhangyu<zhangyub@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "environments.h"
+#include "global/grandsearch_global.h"
 
 #include "gui/mainwindow.h"
 #include "gui/searchconfig/configwidget.h"
@@ -29,6 +12,10 @@
 #include "contacts/services/grandsearchservice.h"
 #include "contacts/services/grandsearchserviceadaptor.h"
 #include "business/config/accessrecord/accessrecord.h"
+#include "buryingpoint/basicpoint.h"
+#include "buryingpoint/buryingpointfactory.h"
+#include "buryingpoint/eventlogutil/eventlogutil.h"
+#include "business/config/searchconfig.h"
 
 #include <DApplication>
 #include <DWidgetUtil>
@@ -41,6 +28,7 @@
 
 #include <unistd.h>
 
+GRANDSEARCH_USE_NAMESPACE
 DGUI_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 DCORE_USE_NAMESPACE
@@ -139,6 +127,13 @@ int main(int argc, char *argv[])
             return -1;
         }
 
+        {
+            QScopedPointer<GrandSearch::burying_point::BasicPoint> p(GrandSearch::burying_point::BuryingPointFactory::instance()
+                                                                     ->createData(GrandSearch::burying_point::BuryingPointEventId::Launch));
+            auto data = p->assemblingData();
+            GrandSearch::burying_point::EventLogUtil::instance()->writeEvent(data);
+        }
+
         return app.exec();
     }
 }
