@@ -1,26 +1,12 @@
-/*
- * Copyright (C) 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     houchengqiu<houchengqiu@uniontech.com>
- *
- * Maintainer: wangchunlin<wangchunlin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 extern "C" {
 #include <ctype.h>
 }
+#include <gio/gdesktopappinfo.h>
+#include <gio/gio.h>
 
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
@@ -31,6 +17,9 @@ extern "C" {
 #include "global/searchhelper.h"
 #include "contacts/interface/daemongrandsearchinterface.h"
 #include "business/config/accessrecord/accessrecord.h"
+#include "buryingpoint/eventlogutil/eventlogutil.h"
+#include "buryingpoint/basicpoint.h"
+#include "buryingpoint/buryingpointfactory.h"
 
 #include <DArrowRectangle>
 #include <DDesktopEntry>
@@ -318,7 +307,7 @@ void Utils::updateItemsWeight(MatchedItemMap &map, const QString &content)
  * @param item 搜索结果
  * @return 支持权重计算则返回true
  */
-bool Utils::setWeightMethod(GrandSearch::MatchedItem &item)
+bool Utils::setWeightMethod(MatchedItem &item)
 {
     QVariantHash ext = item.extra.toHash();
 
@@ -455,7 +444,7 @@ int Utils::calcWeightByDateDiff(const qint64 &diff, const int &type)
  * @param keys 关键字
  * @return 权重
  */
-double Utils::calcAppWeight(const GrandSearch::MatchedItem &item, const QStringList &keys)
+double Utils::calcAppWeight(const MatchedItem &item, const QStringList &keys)
 {
     double weight = 0;
     for (const QString &key : keys) {
@@ -470,7 +459,7 @@ double Utils::calcAppWeight(const GrandSearch::MatchedItem &item, const QStringL
     return weight;
 }
 
-double Utils::calcSettingWeight(const GrandSearch::MatchedItem &item, const QStringList &keys)
+double Utils::calcSettingWeight(const MatchedItem &item, const QStringList &keys)
 {
     double weight = 0;
     for (const QString &key : keys) {
@@ -580,7 +569,7 @@ void Utils::packageBestMatch(MatchedItemMap &map, int maxQuantity)
     }
 }
 
-double Utils::calcRecordWeight(const GrandSearch::MatchedItem &item)
+double Utils::calcRecordWeight(const MatchedItem &item)
 {
     auto recordHash = AccessRecord::instance()->getRecord();
 
@@ -764,6 +753,8 @@ bool Utils::openMatchedItem(const MatchedItem &item)
         result = openFile(item);
     }
 
+    Utils::clickItemPoint(item);
+
     return result;
 }
 
@@ -987,3 +978,21 @@ bool Utils::isWayland()
 
     return wayland;
 }
+
+void Utils::clickItemPoint(const MatchedItem &item)
+{
+    QScopedPointer<burying_point::BasicPoint> p(burying_point::BuryingPointFactory::instance()
+                                                ->createData(burying_point::BuryingPointEventId::ClickItem));
+    QVariantMap data;
+    if (item.searcher == GRANDSEARCH_CLASS_APP_DESKTOP) {   // 应用
+        data.insert("category", "app");
+    } else if (item.searcher == GRANDSEARCH_CLASS_WEB_STATICTEXT) { // web
+        data.insert("category", "web");
+    } else if (item.searcher == GRANDSEARCH_CLASS_SETTING_CONTROLCENTER) {  // 设置
+        data.insert("category", "setting");
+    } else {
+        data.insert("category", item.type);
+    }
+    p->setAdditionalData(data);
+    burying_point::EventLogUtil::instance()->writeEvent(p->assemblingData());
+}
